==> kdeutils-4.1.0.tar.bz2: kdeutils-4.1.0/okteta/program/oktetakakao/controllers/view/search/searchjob.h <==
/*
    This file is part of the Okteta Kakao module, part of the KDE project.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SEARCHJOB_H
#define SEARCHJOB_H

// Qt
#include <QtCore/QObject>
#include <QtCore/QByteArray>

namespace KHECore {
class KAbstractByteArrayModel;
}

class SearchJob : public QObject // not yet: KJob
{
  Q_OBJECT

  public:
    SearchJob( const KHECore::KAbstractByteArrayModel *model,
               const QByteArray &searchData, int startIndex, bool findForward );

  public:
    int exec();

  protected Q_SLOTS:
    void onBytesSearched();

  protected:
    const KHECore::KAbstractByteArrayModel *mByteArrayModel;

    const QByteArray mSearchData;
    int mStartIndex;
    bool mFindForward;
};

inline SearchJob::SearchJob( const KHECore::KAbstractByteArrayModel *model,
               const QByteArray &searchData, int startIndex, bool findForward )
 : mByteArrayModel( model ), mSearchData( searchData ), mStartIndex( startIndex), mFindForward( findForward )
{}

#endif

==> kdeutils-4.2.0.tar.bz2: kdeutils-4.2.0/okteta/program/oktetakakao/controllers/view/search/searchjob.h <==
/*
    This file is part of the Okteta Kakao module, part of the KDE project.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SEARCHJOB_H
#define SEARCHJOB_H

// Qt
#include <QtCore/QObject>
#include <QtCore/QByteArray>

namespace KHECore {
class AbstractByteArrayModel;
}

class SearchJob : public QObject // not yet: KJob
{
  Q_OBJECT

  public:
    SearchJob( const KHECore::AbstractByteArrayModel *model,
               const QByteArray &searchData, int startIndex, bool findForward );

  public:
    int exec();

  protected Q_SLOTS:
    void onBytesSearched();

  protected:
    const KHECore::AbstractByteArrayModel *mByteArrayModel;

    const QByteArray mSearchData;
    int mStartIndex;
    bool mFindForward;
};

inline SearchJob::SearchJob( const KHECore::AbstractByteArrayModel *model,
               const QByteArray &searchData, int startIndex, bool findForward )
 : mByteArrayModel( model ), mSearchData( searchData ), mStartIndex( startIndex), mFindForward( findForward )
{}

#endif
